Welcome to rpycocotools's documentation!
========================================
The `rpycocotools` package provides tools to load, manipulate, convert and visualize COCO format datasets.

This package aims to provide similar functionalities to the `pycocotools package <https://pypi.org/project/pycocotools/>`_ / `cocoapi <https://github.com/cocodataset/cocoapi>`_ with additionnal utilities such as conversion between dataset formats. It also aims to have a better documentation and a more readable implementation.

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    quickstart
    examples
    dataset
    segmentation_masks



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
